IwadRuntimeBindings class
Bindings for src/iwadr.h.
Regenerate bindings with dart run ffigen --config ffigen.yaml.
Constructors
- IwadRuntimeBindings(DynamicLibrary dynamicLibrary)
-
The symbols are looked up in
dynamicLibrary. -
IwadRuntimeBindings.fromLookup(Pointer<
T> lookup<T extends NativeType>(String symbolName) ) -
The symbols are looked up with
lookup.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
iwadr_audio_active_voice_count(
) → int -
iwadr_audio_callback_count(
) → int -
iwadr_audio_clip_count(
) → int -
iwadr_audio_is_started(
) → int -
iwadr_audio_is_suspended(
) → int -
iwadr_audio_max_callback_frame_count(
) → int -
iwadr_audio_max_jump_milli(
) → int -
iwadr_audio_peak_output_milli(
) → int -
iwadr_audio_sample_rate(
) → int -
iwadr_audio_set_suspended(
int suspended) → void -
iwadr_audio_started_sound_count(
) → int -
iwadr_build_local_ticcmd(
Pointer< Uint8> out, int out_len) → int -
iwadr_copy_frame_rgba(
Pointer< Uint8> out, int out_len) → int -
iwadr_current_weapon_slot(
) → int -
iwadr_has_quit(
) → int -
iwadr_is_advance_active(
) → int -
iwadr_is_gameplay_active(
) → int -
iwadr_is_player_dead(
) → int -
iwadr_is_quit_confirm_active(
) → int -
iwadr_is_save_name_active(
) → int -
iwadr_is_started(
) → int -
iwadr_key_event(
int input_key, int pressed) → void -
iwadr_last_error(
) → Pointer< Char> -
iwadr_load_game(
int slot) → int -
iwadr_max_players(
) → int -
iwadr_mouse_event(
int buttons, int delta_x, int delta_y) → void -
iwadr_multiplayer_is_supported(
) → int -
iwadr_music_is_initialized(
) → int -
iwadr_music_play_count(
) → int -
iwadr_music_register_count(
) → int -
iwadr_opl_max_jump_milli(
) → int -
iwadr_opl_mixed_frame_count(
) → int -
iwadr_opl_nonzero_mix_count(
) → int -
iwadr_opl_peak_output_milli(
) → int -
iwadr_opl_peak_sample(
) → int -
iwadr_owned_weapon_slots_mask(
) → int -
iwadr_poll_mouse_delta(
Pointer< Int> delta_x, Pointer<Int> delta_y) → int -
iwadr_request_weapon_slot(
int slot) → void -
iwadr_run_synchronized_tic(
Pointer< Uint8> commands, Pointer<Int> present, int player_count) → int -
iwadr_save_game(
int slot, Pointer< Char> description) → int -
iwadr_save_game_exists(
int slot) → int -
iwadr_save_game_size(
int slot) → int -
iwadr_save_generation(
) → int -
iwadr_screen_height(
) → int -
iwadr_screen_width(
) → int -
iwadr_set_mouse_capture(
int enabled) → int -
iwadr_set_suspended(
int suspended) → void -
iwadr_set_temp_dir(
Pointer< Char> temp_dir) → void -
iwadr_shutdown(
) → void -
iwadr_start(
Pointer< Char> iwad_path) → int -
iwadr_start_multiplayer(
Pointer< Char> iwad_path, int player_count, int local_player, int deathmatch, int episode, int map, int skill, int no_monsters, int fast_monsters, int respawn_monsters, int ticdup_value) → int -
iwadr_start_new_game(
int skill, int episode, int map) → int -
iwadr_sync_checksum(
) → int -
iwadr_ticcmd_size(
) → int -
iwadr_tick(
) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited